MINOR: stats: replace the ST_* uri_auth flags with STAT_*

We used to rely on some config flags defined in uri_auth.h set during
parsing, and another set of STAT_* flags defined in stats.h set at run
time, with a somewhat gray area between the two sets. This is confusing
in the stats code as both are called "flags" in various functions and
it's quite hard to know which one describes what.

This patch cleans this up by replacing all ST_* by a newly assigned
value from the STAT_* set so that we can now use unified flags to
describe both the configuration and the current state. There is no
functional change at all.
diff --git a/src/uri_auth.c b/src/uri_auth.c
index dcfa5e0..352737a 100644
--- a/src/uri_auth.c
+++ b/src/uri_auth.c
@@ -17,6 +17,7 @@
 #include <common/config.h>
 #include <common/uri_auth.h>
 
+#include <types/stats.h>
 #include <proto/log.h>
 
 /*
@@ -108,7 +109,7 @@
 }
 
 /*
  * Returns a default uri_auth with ST_SHNODE flag enabled and
  * <node> set as the name if it is not empty.
  * Uses the pointer provided if not NULL and not initialized.
  */
@@ -126,7 +127,7 @@
 	if ((u = stats_check_init_uri_auth(root)) == NULL)
 		goto out_u;
 
-	if (!stats_set_flag(root, ST_SHNODE))
+	if (!stats_set_flag(root, STAT_SHNODE))
 		goto out_u;
 
 	if (node_copy) {	
@@ -143,7 +144,7 @@
 }
 
 /*
  * Returns a default uri_auth with ST_SHDESC flag enabled and
  * <description> set as the desc if it is not empty.
  * Uses the pointer provided if not NULL and not initialized.
  */
@@ -161,7 +162,7 @@
 	if ((u = stats_check_init_uri_auth(root)) == NULL)
 		goto out_u;
 
-	if (!stats_set_flag(root, ST_SHDESC))
+	if (!stats_set_flag(root, STAT_SHDESC))
 		goto out_u;
 
 	if (desc_copy) {
@@ -108,7 +109,7 @@
 
 /*
- * Returns a default uri_auth with ST_SHNODE flag enabled and
+ * Returns a default uri_auth with STAT_SHNODE flag enabled and
  * <node> set as the name if it is not empty.
  * Uses the pointer provided if not NULL and not initialized.
@@ -143,7 +144,7 @@
 
 /*
- * Returns a default uri_auth with ST_SHDESC flag enabled and
+ * Returns a default uri_auth with STAT_SHDESC flag enabled and
  * <description> set as the desc if it is not empty.
  * Uses the pointer provided if not NULL and not initialized.